__version__ = '1.0.7'

from .inform import (
    indent, cull, is_str, is_iterable, is_collection,
    Color, fmt, os_error, conjoin, plural, InformantGenerator, Inform,
    log, comment, codicil, narrate, display, output, debug, warn, error, fatal, 
    panic, done, terminate, terminate_if_errors, errors_accrued, Error
)



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open('README.rst') as f:
    readme = f.read()

setup(
    name='inform',
    version='1.0.7',
    description='print & logging utilities for communicating with user',
    long_description=readme,
    author="Ken Kundert",
    author_email='inform@nurdletech.com',
    url='https://github.com/kenkundert/inform',
    license='GPLv3+',
    zip_safe=True,
    packages=['inform'],
    install_requires=[
        'arrow',
        'six',
    ],
    keywords=[
        'inform',
        'logging',
        'printing',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Natural Language :: English',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Utilities',
    ],
)
